/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package net.java.truelicense.core;

import java.security.GeneralSecurityException;
import net.java.truelicense.core.io.Sink;

/**
 * Defines the life cycle management operations for license keys in vendor
 * applications alias key tools.
 * <p>
 * Applications have no need to implement this interface and should not do so
 * because it may be subject to expansion in future versions.
 *
 * @see    LicenseVendorContext
 * @author Christian Schlichtherle
 */
public interface LicenseVendorManager
extends LicenseSubjectProvider, LicenseParametersProvider {

    /**
     * Processes the given input license and saves the resulting license key to
     * the given sink.
     * Performing this operation requires prior
     * {@linkplain LicenseAuthorization#clearCreate authorization}.
     *
     * @param  input the input license to process.
     * @param  sink the sink for saving the license key with the output license.
     * @return The duplicated,
     *         {@linkplain LicenseInitialization#initialize initialized}
     *         and
     *         {@linkplain LicenseValidation#validate validated} output license.
     */
    License create(License input, Sink sink) throws GeneralSecurityException;
}
