/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package net.java.truelicense.core.auth;

import javax.annotation.concurrent.Immutable;
import net.java.truelicense.core.codec.Codec;
import net.java.truelicense.core.io.MemoryStore;
import net.java.truelicense.core.io.Source;

/**
 * Uses a {@link Codec} to decode an artifact.
 *
 * @param  <A> The type of the encoded artifact.
 * @author Christian Schlichtherle
 */
@Immutable
final class EncodedArtifact<A> implements Artifactory<A> {

    private final Codec codec;
    private final Source source;

    /**
     * Constructs an encoded artifact.
     *
     * @param encodedArtifact the encoded representation of the artifact.
     * @param codec the codec for decoding the artifact.
     */
    EncodedArtifact(
            final Codec codec,
            final byte[] encodedArtifact) {
        this(codec, source(encodedArtifact));
    }

    EncodedArtifact(final Codec codec, final Source source) {
        assert null != codec;
        this.codec = codec;
        assert null != source;
        this.source = source;
    }

    private static Source source(final byte[] encodedArtifact) {
        final MemoryStore store = new MemoryStore();
        store.data(encodedArtifact);
        return store;
    }

    @Override
    @SuppressWarnings("unchecked")
    public A decode() throws Exception { return (A) codec.decode(source); }
}
